@@ -1,4 +1,3 @@
-
 # Source https://github.com/Leaflet/Leaflet.heat
 heatmapDependency <- function() {
   list(
@@ -43,7 +42,7 @@ heatmapDependency <- function() {
 #' @examples
 #' leaflet(quakes) %>%
 #'   addProviderTiles(providers$CartoDB.DarkMatter) %>%
-#'   setView( 178, -20, 5 ) %>%
+#'   setView(178, -20, 5) %>%
 #'   addHeatmap(
 #'     lng = ~long, lat = ~lat, intensity = ~mag,
 #'     blur = 20, max = 0.05, radius = 15
@@ -51,25 +50,29 @@ heatmapDependency <- function() {
 #'
 #' ## for more examples see
 #' # browseURL(system.file("examples/heatmaps.R", package = "leaflet.extras"))
-addHeatmap = function(
-  map, lng = NULL, lat = NULL, intensity = NULL, layerId = NULL, group = NULL,
-  minOpacity = 0.05,
-  max = 1.0, radius = 25,
-  blur = 15, gradient = NULL, cellSize = NULL,
-  data = leaflet::getMapData(map)
-) {
-  map$dependencies <- c(map$dependencies,
-                        heatmapDependency())
+addHeatmap <- function(
+    map, lng = NULL, lat = NULL, intensity = NULL, layerId = NULL, group = NULL,
+    minOpacity = 0.05,
+    max = 1.0, radius = 25,
+    blur = 15, gradient = NULL, cellSize = NULL,
+    data = leaflet::getMapData(map)) {
+  map$dependencies <- c(
+    map$dependencies,
+    heatmapDependency()
+  )
 
-  #convert gradient to expected format from leaflet
-  if (!is.null(gradient) && !is.function(gradient)) {
-      gradient <- colorNumeric( gradient, 0:1 )
-      gradient <- as.list(gradient(0:20 / 20))
-      names(gradient) <- as.character(0:20 / 20)
+  # convert gradient to expected format from leaflet
+  if (!is.null(gradient)) {
+    if (!is.function(gradient)) {
+      gradient <- colorNumeric(gradient, 0:1, alpha = TRUE)
+    }
+    gradient <- as.list(gradient(0:20 / 20))
+    names(gradient) <- as.character(0:20 / 20)
   }
 
-  pts = leaflet::derivePoints(
-    data, lng, lat, missing(lng), missing(lat), "addHeatmap")
+  pts <- leaflet::derivePoints(
+    data, lng, lat, missing(lng), missing(lat), "addHeatmap"
+  )
 
   if (is.null(intensity)) {
     points <- cbind(pts$lat, pts$lng)
@@ -100,13 +103,12 @@ addHeatmap = function(
 #' Can be a "string" or a JS function, or NULL.
 #' @rdname heatmap
 #' @export
-addGeoJSONHeatmap = function(
-  map, geojson, layerId = NULL, group = NULL,
-  intensityProperty = NULL,
-  minOpacity = 0.05,
-  max = 1.0, radius = 25,
-  blur = 15, gradient = NULL, cellSize = NULL
-  ) {
+addGeoJSONHeatmap <- function(
+    map, geojson, layerId = NULL, group = NULL,
+    intensityProperty = NULL,
+    minOpacity = 0.05,
+    max = 1.0, radius = 25,
+    blur = 15, gradient = NULL, cellSize = NULL) {
   map$dependencies <- c(map$dependencies, omnivoreDependencies())
   map$dependencies <- c(map$dependencies, heatmapDependency())
 
@@ -121,7 +123,8 @@ addGeoJSONHeatmap = function(
       blur = blur,
       gradient = gradient,
       cellSize = cellSize
-    )))
+    ))
+  )
 }
 
 #' Adds a heatmap with data from a KML file/url
@@ -141,17 +144,17 @@ addGeoJSONHeatmap = function(
 #'     kml,
 #'     markerType = "circleMarker",
 #'     stroke = FALSE, fillColor = "black", fillOpacity = 1,
-#'     markerOptions = markerOptions(radius = 1))
+#'     markerOptions = markerOptions(radius = 1)
+#'   )
 #'
 #' ## for more examples see
 #' # browseURL(system.file("examples/KML.R", package = "leaflet.extras"))
-addKMLHeatmap = function(
-  map, kml, layerId = NULL, group = NULL,
-  intensityProperty = NULL,
-  minOpacity = 0.05,
-  max = 1.0, radius = 25,
-  blur = 15, gradient = NULL, cellSize = NULL
-  ) {
+addKMLHeatmap <- function(
+    map, kml, layerId = NULL, group = NULL,
+    intensityProperty = NULL,
+    minOpacity = 0.05,
+    max = 1.0, radius = 25,
+    blur = 15, gradient = NULL, cellSize = NULL) {
   map$dependencies <- c(map$dependencies, omnivoreDependencies())
   map$dependencies <- c(map$dependencies, heatmapDependency())
 
@@ -166,7 +169,8 @@ addKMLHeatmap = function(
       blur = blur,
       gradient = gradient,
       cellSize = cellSize
-    )))
+    ))
+  )
 }
 
 #' Adds a heatmap with data from a CSV file/url
@@ -175,13 +179,12 @@ addKMLHeatmap = function(
 #' Use \code{\link{csvParserOptions}}() to supply csv parser options.
 #' @rdname heatmap
 #' @export
-addCSVHeatmap = function(
-  map, csv, csvParserOptions, layerId = NULL, group = NULL,
-  intensityProperty = NULL,
-  minOpacity = 0.05,
-  max = 1.0, radius = 25,
-  blur = 15, gradient = NULL, cellSize = NULL
-  ) {
+addCSVHeatmap <- function(
+    map, csv, csvParserOptions, layerId = NULL, group = NULL,
+    intensityProperty = NULL,
+    minOpacity = 0.05,
+    max = 1.0, radius = 25,
+    blur = 15, gradient = NULL, cellSize = NULL) {
   map$dependencies <- c(map$dependencies, omnivoreDependencies())
   map$dependencies <- c(map$dependencies, heatmapDependency())
 
@@ -197,20 +200,20 @@ addCSVHeatmap = function(
       gradient = gradient,
       cellSize = cellSize
     )),
-    csvParserOptions)
+    csvParserOptions
+  )
 }
 
 #' Adds a heatmap with data from a GPX file/url
 #' @param gpx The GPX url or contents as string.
 #' @rdname heatmap
 #' @export
-addGPXHeatmap = function(
-  map, gpx, layerId = NULL, group = NULL,
-  intensityProperty = NULL,
-  minOpacity = 0.05,
-  max = 1.0, radius = 25,
-  blur = 15, gradient = NULL, cellSize = NULL
-  ) {
+addGPXHeatmap <- function(
+    map, gpx, layerId = NULL, group = NULL,
+    intensityProperty = NULL,
+    minOpacity = 0.05,
+    max = 1.0, radius = 25,
+    blur = 15, gradient = NULL, cellSize = NULL) {
   map$dependencies <- c(map$dependencies, omnivoreDependencies())
   map$dependencies <- c(map$dependencies, heatmapDependency())
 
@@ -225,20 +228,21 @@ addGPXHeatmap = function(
       blur = blur,
       gradient = gradient,
       cellSize = cellSize
-    )))
+    ))
+  )
 }
 
 
 #' removes the heatmap
 #' @rdname heatmap
 #' @export
-removeHeatmap = function(map, layerId) {
-    leaflet::invokeMethod(map, leaflet::getMapData(map), "removeHeatmap", layerId)
+removeHeatmap <- function(map, layerId) {
+  leaflet::invokeMethod(map, leaflet::getMapData(map), "removeHeatmap", layerId)
 }
 
 #' clears the heatmap
 #' @rdname heatmap
 #' @export
-clearHeatmap = function(map) {
-    leaflet::invokeMethod(map, NULL, "clearHeatmap")
+clearHeatmap <- function(map) {
+  leaflet::invokeMethod(map, NULL, "clearHeatmap")
 }
