@@ -1,14 +1,13 @@
 leafletSearchDependencies <- function() {
   list(
-    # // "fuse.js": "3.2.0",
-    # // "leaflet-search": "2.3.7",
-    html_dep_prod("fuse_js", "3.2.0"),
-    html_dep_prod("lfx-search", "2.3.7", has_style = TRUE, has_binding = TRUE)
+    html_dep_prod("fuse_js", "7.0.0"),
+    html_dep_prod("lfx-search", "4.0.0", has_style = TRUE, has_binding = TRUE)
   )
 }
 
+
 #' Options for search control.
-#' @param url url for search by ajax request, ex: "search.php?q={s}". Can be function that returns string for dynamic parameter setting.
+#' @param url url for search by ajax request, ex: `search.php?q=\{s\}`. Can be function that returns string for dynamic parameter setting.
 #' @param sourceData function that fill _recordsCache, passed searching text by first param and callback in second.
 #' @param jsonpParam jsonp param name for search by jsonp service, ex: "callback".
 #' @param propertyLoc field for remapping location, using array: ["latname","lonname"] for select double fields(ex. ["lat","lon"] ) support dotted format: "prop.subprop.title".
@@ -36,14 +35,15 @@ leafletSearchDependencies <- function() {
 #' @param textPlaceholder placeholder value.
 #' @param position "topleft".
 #' @param hideMarkerOnCollapse remove circle and marker on search control collapsed.
+#' @param marker Let's you set the icon. Can be an icon made by \code{\link[leaflet]{makeIcon}} or \code{\link[leaflet]{makeAwesomeIcon}}
 #' @rdname search-options
 #' @export
 searchOptions <- function(
-    url = "",
+    url = NULL,
     sourceData = NULL,
     jsonpParam = NULL,
-    propertyLoc = "loc",
-    propertyName = "title",
+    propertyLoc = NULL,
+    propertyName = NULL,
     formatData = NULL,
     filterData = NULL,
     moveToLocation = TRUE,
@@ -66,38 +66,49 @@ searchOptions <- function(
     textCancel = "Cancel",
     textPlaceholder = "Search...",
     position = "topleft",
-    hideMarkerOnCollapse = FALSE
-) {
-    leaflet::filterNULL(list(
-        url = url,
-        sourceData = sourceData,
-        jsonpParam = jsonpParam,
-        propertyLoc = propertyLoc,
-        propertyName = propertyName,
-        formatData = formatData,
-        filterData = filterData,
-        moveToLocation = moveToLocation,
-        zoom = zoom,
-        buildTip = buildTip,
-        container = container,
-        minLength = minLength,
-        initial = initial,
-        casesensitive = casesensitive,
-        autoType = autoType,
-        delayType = delayType,
-        tooltipLimit = tooltipLimit,
-        tipAutoSubmit = tipAutoSubmit,
-        firstTipSubmit = firstTipSubmit,
-        autoResize = autoResize,
-        collapsed = collapsed,
-        autoCollapse = autoCollapse,
-        autoCollapseTime = autoCollapseTime,
-        textErr = textErr,
-        textCancel = textCancel,
-        textPlaceholder = textPlaceholder,
-        position = position,
-        hideMarkerOnCollapse = hideMarkerOnCollapse
-    ))
+    hideMarkerOnCollapse = FALSE,
+    marker = list(
+      icon = NULL,
+      animate = TRUE,
+      circle = list(
+        radius = 10,
+        weight = 3,
+        color = "#e03",
+        stroke = TRUE,
+        fill = FALSE
+      )
+    )) {
+  leaflet::filterNULL(list(
+    url = url,
+    sourceData = sourceData,
+    jsonpParam = jsonpParam,
+    propertyLoc = propertyLoc,
+    propertyName = propertyName,
+    formatData = formatData,
+    filterData = filterData,
+    moveToLocation = moveToLocation,
+    zoom = zoom,
+    buildTip = buildTip,
+    container = container,
+    minLength = minLength,
+    initial = initial,
+    casesensitive = casesensitive,
+    autoType = autoType,
+    delayType = delayType,
+    tooltipLimit = tooltipLimit,
+    tipAutoSubmit = tipAutoSubmit,
+    firstTipSubmit = firstTipSubmit,
+    autoResize = autoResize,
+    collapsed = collapsed,
+    autoCollapse = autoCollapse,
+    autoCollapseTime = autoCollapseTime,
+    textErr = textErr,
+    textCancel = textCancel,
+    textPlaceholder = textPlaceholder,
+    position = position,
+    hideMarkerOnCollapse = hideMarkerOnCollapse,
+    marker = marker
+  ))
 }
 
 #' Add a OSM search control to the map.
@@ -107,11 +118,14 @@ searchOptions <- function(
 #' @return modified map
 #' @rdname search-geocoding
 #' @export
-addSearchOSM <- function(
-  map,
-  options = searchOptions(autoCollapse = TRUE, minLength = 2)
-) {
+addSearchOSM <- function(map,
+                         options = searchOptions(autoCollapse = TRUE, minLength = 2)) {
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
+
+  result <- makeSearchIcon(map, options)
+  map <- result$map
+  options$marker$icon <- result$icon
+
   invokeMethod(
     map,
     getMapData(map),
@@ -120,6 +134,23 @@ addSearchOSM <- function(
   )
 }
 
+#' Add a OSM search control to the map.
+#'
+#' @param map a map widget object
+#' @param text The search text
+#' @return modified map
+#' @rdname search-geocoding
+#' @export
+searchOSMText <- function(map, text = "") {
+  map$dependencies <- c(map$dependencies, leafletSearchDependencies())
+  invokeMethod(
+    map,
+    NULL,
+    "searchOSMText",
+    text
+  )
+}
+
 #' Removes the OSM search control from the map.
 #'
 #' @return modified map
@@ -134,6 +165,19 @@ removeSearchOSM <- function(map) {
   )
 }
 
+#' Clears the search marker
+#'
+#' @return modified map
+#' @rdname search-geocoding
+#' @export
+clearSearchOSM <- function(map) {
+  invokeMethod(
+    map,
+    getMapData(map),
+    "clearSearchOSM"
+  )
+}
+
 #' @param showSearchLocation Boolean. If TRUE displays a Marker on the searched location's coordinates.
 #' @param showBounds Boolean. If TRUE show the bounding box of the found feature.
 #' @param showFeature Boolean. If TRUE show the found feature.
@@ -142,23 +186,55 @@ removeSearchOSM <- function(map) {
 #'   For this to be effective one of \code{showSearchLocation}, \code{showBounds}, \code{showFeature} shoule also be TRUE.
 #' @param displayText Boolean. If TRUE show a text box with found location's name on the map.
 #' @param group String. An optional group to hold all the searched locations and their results.
+#' @param marker Let's you set the icon. Can be an icon made by \code{\link[leaflet]{makeIcon}} or \code{\link[leaflet]{makeAwesomeIcon}}
+#' @param showFeatureOptions A list of styling options for the found feature
+#' @param showBoundsOptions A list of styling options for the bounds of the found feature
+#' @param showHighlightOptions A list of styling options for the hover effect of a found feature
 #' @return modified map
 #' @rdname search-geocoding
 #' @export
 addReverseSearchOSM <- function(
-  map,
-  showSearchLocation = TRUE,
-  showBounds = FALSE,
-  showFeature = TRUE,
-  fitBounds = TRUE,
-  displayText = TRUE,
-  group = NULL) {
+    map,
+    showSearchLocation = TRUE,
+    showBounds = FALSE,
+    showFeature = TRUE,
+    fitBounds = TRUE,
+    displayText = TRUE,
+    group = NULL,
+    marker = list(
+      icon = NULL
+    ),
+    showFeatureOptions = list(
+      weight = 2,
+      color = "red",
+      dashArray = "5,10",
+      fillOpacity = 0.2,
+      opacity = 0.5
+    ),
+    showBoundsOptions = list(
+      weight = 2,
+      color = "#444444",
+      dashArray = "5,10",
+      fillOpacity = 0.2,
+      opacity = 0.5
+    ),
+    showHighlightOptions = list(
+      opacity = 0.8,
+      fillOpacity = 0.5,
+      weight = 5
+    )) {
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
   if (displayText == TRUE) {
     map <- map %>%
       addControl("Click anywhere on the map to reverse geocode",
-                 position = "topright", layerId = "reverseSearchOSM")
+        position = "topright", layerId = "reverseSearchOSM"
+      )
   }
+
+  result <- makeSearchIcon(map, list("marker" = marker))
+  map <- result$map
+  marker$icon <- result$icon
+
   invokeMethod(
     map,
     getMapData(map),
@@ -167,7 +243,11 @@ addReverseSearchOSM <- function(
       showSearchLocation = showSearchLocation,
       fitBounds = fitBounds,
       showBounds = showBounds,
-      showFeature = showFeature
+      showFeature = showFeature,
+      marker = marker,
+      showFeatureOptions = showFeatureOptions,
+      showBoundsOptions = showBoundsOptions,
+      showHighlightOptions = showHighlightOptions
     ),
     group
   )
@@ -187,18 +267,16 @@ addReverseSearchOSM <- function(
 #' ## for more examples see
 #' # browseURL(system.file("examples/search.R", package = "leaflet.extras"))
 #'
-#'
 #' @export
 addSearchGoogle <- function(
-  map,
-  apikey = Sys.getenv("GOOGLE_MAP_GEOCODING_KEY"),
-  options = searchOptions(autoCollapse = TRUE, minLength = 2)
-) {
+    map,
+    apikey = Sys.getenv("GOOGLE_MAP_GEOCODING_KEY"),
+    options = searchOptions(autoCollapse = TRUE, minLength = 2)) {
   url <- "https://maps.googleapis.com/maps/api/js?v=3"
-  if (is.null(apikey)) {
+  if (is.null(apikey) || apikey == "") {
     warning("Google Geocoding works best with an apikey")
   } else {
-   url <- paste0(url, "&key=", apikey)
+    url <- paste0(url, "&key=", apikey)
   }
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
   invokeMethod(
@@ -228,25 +306,26 @@ removeSearchGoogle <- function(map) {
 #' @rdname search-geocoding
 #' @export
 addReverseSearchGoogle <- function(
-  map,
-  apikey = Sys.getenv("GOOGLE_MAP_GEOCODING_KEY"),
-  showSearchLocation = TRUE,
-  showBounds = FALSE,
-  showFeature = TRUE,
-  fitBounds = TRUE,
-  displayText = TRUE,
-  group = NULL) {
+    map,
+    apikey = Sys.getenv("GOOGLE_MAP_GEOCODING_KEY"),
+    showSearchLocation = TRUE,
+    showBounds = FALSE,
+    showFeature = TRUE,
+    fitBounds = TRUE,
+    displayText = TRUE,
+    group = NULL) {
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
   url <- "https://maps.googleapis.com/maps/api/js?v=3"
-  if (is.null(apikey)) {
+  if (is.null(apikey) || apikey == "") {
     warning("Google Geocoding works best with an apikey")
   } else {
-   url <- paste0(url, "&key=", apikey)
+    url <- paste0(url, "&key=", apikey)
   }
   if (displayText == TRUE) {
     map <- map %>%
       addControl("Click anywhere on the map to reverse geocode",
-                 position = "topright", layerId = "reverseSearchGoogle")
+        position = "topright", layerId = "reverseSearchGoogle"
+      )
   }
   invokeMethod(
     map,
@@ -269,9 +348,8 @@ addReverseSearchGoogle <- function(
 #' @rdname search-geocoding
 #' @export
 addSearchUSCensusBureau <- function(
-  map,
-  options = searchOptions(autoCollapse = TRUE, minLength = 20)
-) {
+    map,
+    options = searchOptions(autoCollapse = TRUE, minLength = 20)) {
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
   invokeMethod(
     map,
@@ -304,13 +382,15 @@ searchFeaturesOptions <- function(
     propertyName = "label",
     initial = FALSE,
     openPopup = FALSE,
-    ...
-) {
-  c(openPopup = openPopup,
+    ...) {
+  c(
+    openPopup = openPopup,
     searchOptions(
-       propertyName = propertyName,
-       initial = initial,
-       ...))
+      propertyName = propertyName,
+      initial = initial,
+      ...
+    )
+  )
 }
 
 
@@ -325,16 +405,20 @@ searchFeaturesOptions <- function(
 addSearchFeatures <- function(
     map,
     targetGroups,
-    options = searchFeaturesOptions()
-) {
-    map$dependencies <- c(map$dependencies, leafletSearchDependencies())
-    invokeMethod(
-        map,
-        getMapData(map),
-        "addSearchFeatures",
-        targetGroups,
-        options
-    )
+    options = searchFeaturesOptions()) {
+  map$dependencies <- c(map$dependencies, leafletSearchDependencies())
+
+  result <- makeSearchIcon(map, options)
+  map <- result$map
+  options$marker$icon <- result$icon
+
+  invokeMethod(
+    map,
+    getMapData(map),
+    "addSearchFeatures",
+    targetGroups,
+    options
+  )
 }
 
 #' Removes the feature search control from the map.
@@ -343,7 +427,7 @@ addSearchFeatures <- function(
 #' @return modified map
 #' @rdname search-features
 #' @export
-removeSearchFeatures <- function(map, clearFeatures =FALSE) {
+removeSearchFeatures <- function(map, clearFeatures = FALSE) {
   map$dependencies <- c(map$dependencies, leafletSearchDependencies())
   invokeMethod(
     map,
@@ -352,3 +436,41 @@ removeSearchFeatures <- function(map, clearFeatures =FALSE) {
     clearFeatures
   )
 }
+
+#' Clears the search marker
+#'
+#' @return modified map
+#' @rdname search-features
+#' @export
+clearSearchFeatures <- function(map) {
+  invokeMethod(
+    map, NULL, "clearSearchFeatures"
+  )
+}
+
+
+makeSearchIcon <- function(map, options) {
+  icon <- options$marker$icon
+  icon <- if (is.null(icon) || all(is.na(icon)) || isFALSE(icon)) NULL else icon
+
+  if (!is.null(icon)) {
+    if (isTRUE(icon)) {
+    } else {
+      if (inherits(icon, "leaflet_awesome_icon")) {
+        map <- addAwesomeMarkersDependencies(map, icon$library)
+        icon$awesomemarker <- TRUE
+      } else {
+        icon$iconUrl <- b64EncodePackedIcons(packStrings(icon$iconUrl))
+        icon$iconRetinaUrl <- b64EncodePackedIcons(packStrings(icon$iconRetinaUrl))
+        icon$shadowUrl <- b64EncodePackedIcons(packStrings(icon$shadowUrl))
+        icon$shadowRetinaUrl <- b64EncodePackedIcons(packStrings(icon$shadowRetinaUrl))
+        if (length(icon$iconSize) == 2 && is.numeric(icon$iconSize[[1]]) && is.numeric(icon$iconSize[[2]])) {
+          icon$iconSize <- list(icon$iconSize)
+        }
+      }
+      icon <- leaflet::filterNULL(icon)
+    }
+  }
+
+  return(list(map = map, icon = icon))
+}
